==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/lt_LT.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Kontaktai",
"Save" => "Išsaugoti",
"Uploading..." => "Įkeliama...",
"Importing..." => "Importuojama...",
"Preparing..." => "Ruošiama...",
"Imported {count} of {total} contacts" => "Importuota {count} iš {total} kontaktų",
"Imported {imported} contacts. {failed} failed." => "Importuota {imported} kontaktų. {failed} nepavyko.",
"An address book called {name} already exists" => "Adresų knyga pavadinimu {group} jau egzistuoja",
"Failed adding address book: {error}" => "Nepavyko pridėti adresų knygos: {error}",
"Failed loading address books: {error}" => "Nepavyko įkelti adresų knygų: {error}",
"Indexing contacts" => "Indeksuojami kontaktai",
"Error." => "Klaida.",
"Add to..." => "Pridėti į...",
"Remove from..." => "Pašalinti iš...",
"Add group..." => "Pridėti grupę...",
"Invalid URL: \"{url}\"" => "Netinkamas URL\" „{url}“",
"There was an error opening a mail composer." => "Buvo klaida atveriant el. laiško redaktorių.",
"Invalid email: \"{url}\"" => "Netinkamas el. paštas",
"Merge failed. Cannot find contact: {id}" => "Suliejimas nepavyko. Nepavyksta rasti kontakto: {id}",
"Merge failed." => "Sulieti nepavyko.",
"Merge failed. Error saving contact." => "Suliejimas nepavyko. Klaida saugant kontaktą.",
"Select photo" => "Nurodykite nuotrauką",
"Network or server error. Please inform administrator." => "Tinklo arba serverio klaida. Prašome informuoti administratorių.",
"Error adding to group." => "Klaida pridedant į grupę.",
"Error removing from group." => "Klaida pašalinant iš grupės.",
"Error setting {name} as favorite." => "Klaida nustatant {name} mėgstamu.",
"Merge contacts" => "Sulieti kontaktus",
"Cancel" => "Atšaukti",
"Add group" => "Pridėti grupę",
"OK" => "Gerai",
"Could not find contact: {id}" => "Nepavyko rasti kontakto: {id}",
"No files selected for upload." => "Nepažymėta jokių failų įkėlimui.",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Įkeliamo failo dydis viršijo šio serverio maksimalų leistiną dydį.",
"Edit profile picture" => "Redaguoti profilio paveikslėlį",
"Crop photo" => "Apkirpti nuotrauką",
"Is this correct?" => "Teisinga?",
"Error parsing date: {date}" => "Klaida apdorojant datą: {date}",
"# groups" => "# grupės",
"Error parsing birthday {bday}: {error}" => "Klaida nagrinėjant gimtadienį {bday}: {error}",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Keletas kontaktų buvo pažymėti ištrinimui, bet dar neištrinti. Prašome palaukti kol jie bus ištrinti.",
"Click to undo deletion of {num} contacts" => "Spauskite, kad atstatyti trynimą {num} kontaktų",
"Cancelled deletion of {num} contacts" => "Atšauktas {num} kontaktų trynimas",
"Add" => "Pridėti",
"Contact is already in this group." => "Kontaktas jau yra grupėje.",
"Contacts are already in this group." => "Kontaktai jau yra grupėje.",
"Couldn't get contact list." => "Nepavyko gauti kontaktų sąrašo.",
"Contact is not in this group." => "Kontaktas nėra šioje grupėje.",
"Contacts are not in this group." => "KontaktaI nėra šioje grupėje.",
"Failed renaming group: {error}" => "Nepavyko pervadinti grupės: {error}",
"A group named {group} already exists" => "Grupė pavadinimu {group} jau egzistuoja",
"You can drag groups to\narrange them as you like." => "Galite tempti grupes, kad\nišrikiuoti jas kaip Jums reikia.",
"Failed adding group: {error}" => "Nepavyko pridėti grupės: {error}",
"All" => "Viskas",
"Favorites" => "Mėgstamiausi",
"Shared by {owner}" => "Bendrina {owner}",
"Not grouped" => "Nesugrupuotas",
"Failed loading groups: {error}" => "Nepavyko įkelti grupių: {error}",
"Please choose the addressbook" => "Prašome pasirinkti adresų knygą",
"Import into..." => "Importuoti į...",
"Error loading import template" => "Klaida įkeliant importavimo ruošinį",
"Import contacts" => "Importuoti kontaktus",
"Import" => "Importuoti",
"Import done" => "Importas baigas",
"Close" => "Užverti",
"Error" => "Klaida",
"Displayname cannot be empty." => "Rodomas vardas negali būti tuščias.",
"Show CardDav link" => "Rodyti CardDAV nuorodą",
"Show read-only VCF link" => "Rodyti tik skaitymui VCF nuorodą",
"Download" => "Atsisiųsti",
"Edit" => "Redaguoti",
"Delete" => "Ištrinti",
"More..." => "Daugiau...",
"Less..." => "Mažiau...",
"Server error! Please inform system administator" => "Serverio klaida! Prašome informuoti administratorių",
"Failed loading photo: {error}" => "Nepavyko įkelti nuotraukos: {error}",
"You do not have permissions to see this contacts" => "Jūs neturite leidimo matyti šių kontaktų",
"Contact not found" => "Kontaktas nerastas",
"You do not have permissions to see these contacts" => "Jūs neturite leidimo matyti šiuos kontaktus",
"You do not have permissions add contacts to the address book" => "Jūs neturite leidimų pridėti kontaktų į šią adresų knygutę",
"You do not have permissions to delete this contact" => "Jūs neturite leidimų ištrinti šį kontaktą",
"Unknown error" => "Neatpažinta klaida",
"You don't have permissions to update the address book." => "Jūs neturite leidimo atnaujinti šią adresų knygutę.",
"You don't have permissions to delete the address book." => "Jūs neturite leidimo ištrinti šią adresų knygutę.",
"Address book not found" => "Adresų knygutė nerasta",
"You do not have permissions to see this contact" => "Jūs neturite leidimo matyti šį kontaktą",
"You do not have permissions to update this contact" => "Jūs neturite leidimo atnaujinti šį kontaktą",
"Property not found" => "Savybė nerasta",
"Unknown IM: " => "Nežinomas IM:",
"{name}'s Birthday" => "{name} gimtadienis",
"Error creating address book" => "Klaida kuriant adresų knygutę",
"Error updating address book" => "Klaida atnaujinant adresų knygutę",
"You do not have permissions to delete the \"%s\" address book" => "Jūs neturite leidimo ištrinti „%s“ adresų knygos",
"Error deleting address book" => "Klaida trinant adresų knygutę",
"Error creating contact." => "Klaida kuriant kontaktą.",
"Error deleting contact." => "Klaida trinant kontaktą.",
"Error retrieving contact." => "Klaida gaunant kontaktą.",
"Error saving contact." => "Klaida išsaugant kontaktą.",
"Error removing contact from other address book." => "Klaida paralinant kontaktą iš kitos adresų knygutės.",
"Couldn't find contact." => "Nepavyko rasti kontakto.",
"Property name is not set." => "Nenustatytas savybės pavadinimas.",
"Property checksum is not set." => "Nenustatyta savybės kontrolinė suma.",
"Information about vCard is incorrect. Please reload the page." => "Informacija apie vCard yra neteisinga. ",
"Error updating contact" => "Klaida atnaujinant kontaktą",
"Error getting user photo" => "Klaida gaunant naudotojo nuotrauką",
"No file was uploaded. Unknown error" => "Failai nebuvo įkelti dėl nežinomos priežasties",
"There is no error, the file uploaded with success" => "Failas įkeltas sėkmingai, be klaidų",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Įkeliamo failo dydis viršija upload_max_filesize nustatymą php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Įkeliamo failo dydis viršija MAX_FILE_SIZE nustatymą, kuris naudojamas HTML formoje.",
"The uploaded file was only partially uploaded" => "Failas buvo įkeltas tik dalinai",
"No file was uploaded" => "Nebuvo įkeltas joks failas",
"Missing a temporary folder" => "Nėra laikinojo katalogo",
"Couldn't load temporary image: " => "Nepavyko įkelti laikiną paveikslėlį:",
"Couldn't save temporary image: " => "Nepavyko išsaugoti laikiną paveikslėlį:",
"No photo path was submitted." => "Nenurodytas nuotraukos kelias. ",
"File doesn't exist:" => "Failas neegzistuoja:",
"Error loading image." => "Klaida įkeliant nuotrauką.",
"Image has been removed from cache" => "Paveikslėlis pašalintas iš talpyklos",
"Error creating temporary image" => "Klaida kuriant laikiną paveikslėlį",
"Error cropping image" => "Klaida apkerpant paveikslėlį",
"Error resizing image" => "Klaida keičiant paveikslėlio dydį",
"Error getting PHOTO property." => "Klaida gaunant nuotraukos  savybes.",
"No group name given." => "Nepateiktas grupės pavadinimas.",
"Error adding group." => "Klaida pridedant grupę.",
"Error renaming group." => "Klaida pervadinant grupę.",
"Failed to write to disk" => "Nepavyko įrašyti į diską",
"Not enough storage available" => "Nepakanka vietos serveryje",
"Attempt to upload blacklisted file:" => "Bandymas įkelti draudžiamą failą:",
"Error uploading contacts to storage." => "Klaida siunčiant kontaktus į saugyklą.",
"Error moving file to imports folder." => "Klaida perkeliant failą į importavimų aplanką.",
"You do not have permissions to import into this address book." => "Jūs neturite leidimo importuoti į šią adresų knygutę.",
"File name missing from request." => "Užklausoje trūksta failo pavadinimo.",
"Attempt to access blacklisted file:" => "bandymas pasiekti draudžiamą failą:",
"No contacts found in: " => "Kontaktų nerasta:",
"No key is given." => "Nepateiktas raktas.",
"No value is given." => "Nepateikta vertė.",
"Could not set preference: " => "Nepavyko nustatyti:",
"Contact" => "Kontaktas",
"Other" => "Kita",
"HomePage" => "Namų puslapis",
"Jabber" => "Jabber",
"Internet call" => "Internetinis skambutis",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Darbas",
"Home" => "Namų",
"Mobile" => "Mobilusis",
"Text" => "Žinučių",
"Voice" => "Balso",
"Message" => "Žinutė",
"Fax" => "Faksas",
"Video" => "Vaizdo",
"Pager" => "Pranešimų gaviklis",
"Internet" => "Internetas",
"Friends" => "Draugai",
"Family" => "Šeima",
"New Contact" => "Naujas kontaktas",
"Group name" => "Grupės pavadinimas",
"New Group" => "Nauja grupė",
"Address books" => "Adresų knygos",
"Display name" => "Rodyti vardą",
"Add Address Book" => "Pridėti adresų knygą",
"Select file..." => "Pasirinkti failą...",
"(De-)select all" => "Nuimti pažymėjimą",
"Sort order" => "Išdėstymo tvarka",
"First- Lastname" => "Vardas- Pavardė",
"Last-, Firstname" => "Pavardė-, Vardas",
"Groups" => "Grupės",
"Favorite" => "Mėgiamas",
"Merge selected" => "Suliejimas pažymėtas",
"Keyboard shortcuts" => "Klaviatūros spartieji klavišai",
"Navigation" => "Navigacija",
"Next contact in list" => "Kitas kontaktas sąraše",
"Previous contact in list" => "Ankstesnis kontaktas sąraše",
"Expand/collapse current addressbook" => "Išskleisti/sutraukti šią adresų knygutę",
"Next addressbook" => "Kita adresų knygutė",
"Previous addressbook" => "Ankstesnė adresų knygutė",
"Actions" => "Veiksmai",
"Refresh contacts list" => "Atnaujinti kontaktų sąrašą",
"Add new contact" => "Pridėti naują kontaktą",
"Add new addressbook" => "Pridėti naują adresų knygą",
"Delete current contact" => "Ištrinti šį kontaktą",
"<h3>You have no contacts in your address book or your address book is disabled.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>Jūs neturite kontaktų savo adresų knygoje, arba adresų knyga yra išjungta.</h3><p>Pridėkite naują kontaktą, arba importuokite turimus kontaktus iš VCF failo.</p>",
"Add contact" => "Pridėti kontaktą",
"Delete group" => "Trinti grupę",
"Rename group" => "Pervadinti grupę",
"Compose mail" => "Sukurti el. laišką",
"Delete current photo" => "Ištrinti šią nuotrauką",
"Edit current photo" => "Redaguoti šią nuotrauką",
"Upload new photo" => "Įkelti naują foto",
"Select photo from ownCloud" => "Pasirinkite nuotrauką iš ownCloud",
"Name" => "Pavadinimas",
"First name" => "Vardas",
"Additional names" => "Papildomi vardai",
"Last name" => "Pavardė",
"Select groups" => "Pasirinkti grupes",
"Select address book" => "Parinkti adresų knygą",
"Nickname" => "Slapyvardis",
"Enter nickname" => "Įveskite slapyvardį",
"Title" => "Pavadinimas",
"Enter title" => "Įveskite pavadinimą",
"Organization" => "Organizacija",
"Enter organization" => "Įveskite organizaciją",
"Birthday" => "Gimtadienis",
"Notes go here..." => "Pastabos rašomo čia...",
"Export as VCF" => "Eksportuoti kaip VCF",
"Add field..." => "Pridėti lauką...",
"Phone" => "Telefonas",
"Email" => "El. Paštas",
"Instant Messaging" => "Tikralaikiai pokalbiai",
"Address" => "Adresas",
"Note" => "Pastaba",
"Web site" => "Svetainė",
"Delete contact" => "Ištrinti kontaktą",
"Preferred" => "Pageidautinas",
"Please specify a valid email address." => "Prašome nurodyti tinkamą el. pašto adresą.",
"someone@example.com" => "kasnors@pavyzdys.lt",
"Mail to address" => "Gavėjo el. pašto adresas",
"Delete email address" => "Ištrinti el. pašto adresus",
"Enter phone number" => "Įveskite telefono numerį",
"Delete phone number" => "Ištrinti telefono numerį",
"Go to web site" => "Eiti į svetainę",
"Delete URL" => "Ištrinti URL",
"View on map" => "Žiūrėti žemėlapyje",
"Delete address" => "Pašalinti adresą",
"Street address" => "Gatvės adresas",
"Postal code" => "Pašto kodas",
"Washington, DC" => "Vašingtono apygarda",
"City" => "Miestas",
"State or province" => "Šalis ar provincija",
"USA" => "JAV",
"Country" => "Šalis",
"Instant Messenger" => "Momentinių žinučių klientas",
"Delete IM" => "Ištrinti IM",
"Active" => "Aktyvus",
"Share" => "Dalintis",
"Export" => "Eksportuoti",
"CardDAV link" => "CardDAV nuoroda",
"CardDAV syncing addresses" => "CardDAV sinchronizavimo adresai",
"more info" => "daugiau informacijos",
"Primary address (Kontact et al)" => "Pirminis adresas",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Adresų knygos",
"New Address Book" => "Nauja adresų knyga",
"Description" => "Aprašymas"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/lt_LT.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Kontaktai",
"Ok" => "Gerai",
"Cancel" => "Atšaukti",
"Save" => "Išsaugoti",
"Edit Addressbook" => "Redaguoti adresų knygą",
"An address book called {name} already exists" => "Adresų knyga pavadinimu {group} jau egzistuoja",
"Failed adding address book: {error}" => "Nepavyko pridėti adresų knygos: {error}",
"Failed loading address books: {error}" => "Nepavyko įkelti adresų knygų: {error}",
"Server error! Please inform system administator" => "Serverio klaida! Prašome informuoti administratorių",
"Indexing contacts" => "Indeksuojami kontaktai",
"Error." => "Klaida.",
"Add to..." => "Pridėti į...",
"Remove from..." => "Pašalinti iš...",
"Add group..." => "Pridėti grupę...",
"Invalid URL: \"{url}\"" => "Netinkamas URL\" „{url}“",
"Invalid email: \"{url}\"" => "Netinkamas el. paštas",
"Merge failed. Cannot find contact: {id}" => "Suliejimas nepavyko. Nepavyksta rasti kontakto: {id}",
"Merge failed." => "Sulieti nepavyko.",
"Merge failed. Error saving contact." => "Suliejimas nepavyko. Klaida saugant kontaktą.",
"Select photo" => "Nurodykite nuotrauką",
"Network or server error. Please inform administrator." => "Tinklo arba serverio klaida. Prašome informuoti administratorių.",
"Error adding to group." => "Klaida pridedant į grupę.",
"Error removing from group." => "Klaida pašalinant iš grupės.",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "Jūs pažymėjote daugiau nei 300 kontaktų.\nTai greičiausiai nepavyks! Spauskite, kad vis tiek bandyti.",
"Error setting {name} as favorite." => "Klaida nustatant {name} mėgstamu.",
"Merge contacts" => "Sulieti kontaktus",
"Add group" => "Pridėti grupę",
"OK" => "Gerai",
"Could not find contact: {id}" => "Nepavyko rasti kontakto: {id}",
"Edit profile picture" => "Redaguoti profilio paveikslėlį",
"Crop photo" => "Apkirpti nuotrauką",
"Error parsing date: {date}" => "Klaida apdorojant datą: {date}",
"# groups" => "# grupės",
"Error parsing birthday {bday}" => "Klaida apdorojant gimtadienį {bday}",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Keletas kontaktų buvo pažymėti ištrinimui, bet dar neištrinti. Prašome palaukti kol jie bus ištrinti.",
"Click to undo deletion of {num} contacts" => "Spauskite, kad atstatyti trynimą {num} kontaktų",
"Cancelled deletion of {num} contacts" => "Atšauktas {num} kontaktų trynimas",
"Add" => "Pridėti",
"Contact is already in this group." => "Kontaktas jau yra grupėje.",
"Contacts are already in this group." => "Kontaktai jau yra grupėje.",
"Couldn't get contact list." => "Nepavyko gauti kontaktų sąrašo.",
"Contact is not in this group." => "Kontaktas nėra šioje grupėje.",
"Contacts are not in this group." => "KontaktaI nėra šioje grupėje.",
"A group named \"{group}\" already exists" => "Grupė pavadinimu „{group}“ jau egzistuoja",
"Failed renaming group: {error}" => "Nepavyko pervadinti grupės: {error}",
"You can drag groups to\narrange them as you like." => "Galite tempti grupes, kad\nišrikiuoti jas kaip Jums reikia.",
"Failed adding group: {error}" => "Nepavyko pridėti grupės: {error}",
"All" => "Viskas",
"Favorites" => "Mėgstamiausi",
"Shared by {owner}" => "Bendrina {owner}",
"Not grouped" => "Nesugrupuotas",
"Failed loading groups: {error}" => "Nepavyko įkelti grupių: {error}",
"Please choose the addressbook" => "Prašome pasirinkti adresų knygą",
"Import into..." => "Importuoti į...",
"Error loading import template" => "Klaida įkeliant importavimo ruošinį",
"Import contacts" => "Importuoti kontaktus",
"Import" => "Importuoti",
"Importing..." => "Importuojama...",
"Import done" => "Importas baigas",
"Close" => "Užverti",
"Failed loading photo: {error}" => "Nepavyko įkelti nuotraukos: {error}",
"You do not have permissions to see this contact" => "Jūs neturite leidimo matyti šį kontaktą",
"Contact not found" => "Kontaktas nerastas",
"You do not have permissions to see these contacts" => "Jūs neturite leidimo matyti šiuos kontaktus",
"You do not have permissions add contacts to the address book" => "Jūs neturite leidimų pridėti kontaktų į šią adresų knygutę",
"You do not have permissions to delete this contact" => "Jūs neturite leidimų ištrinti šį kontaktą",
"Unknown error" => "Neatpažinta klaida",
"You don't have permissions to delete the address book." => "Jūs neturite leidimo ištrinti šią adresų knygutę.",
"Address book not found" => "Adresų knygutė nerasta",
"You do not have permissions to update this contact" => "Jūs neturite leidimo atnaujinti šį kontaktą",
"Property not found" => "Savybė nerasta",
"Unknown IM: " => "Nežinomas IM:",
"{name}'s Birthday" => "{name} gimtadienis",
"Error creating address book" => "Klaida kuriant adresų knygutę",
"You do not have permissions to delete the \"%s\" address book" => "Jūs neturite leidimo ištrinti „%s“ adresų knygos",
"Error deleting address book" => "Klaida trinant adresų knygutę",
"Error creating contact." => "Klaida kuriant kontaktą.",
"Error removing contact from other address book." => "Klaida paralinant kontaktą iš kitos adresų knygutės.",
"Couldn't find contact." => "Nepavyko rasti kontakto.",
"No contact data in request." => "Nėra kontakto duomenų užklausoje.",
"Error merging into contact." => "Klaida suliejant į kontaktą.",
"Error saving contact to backend." => "Klaida išsaugant kontaktą sistemoje.",
"Property name is not set." => "Nenustatytas savybės pavadinimas.",
"Property checksum is not set." => "Nenustatyta savybės kontrolinė suma.",
"Information about vCard is incorrect. Please reload the page." => "Informacija apie vCard yra neteisinga. ",
"Error updating contact" => "Klaida atnaujinant kontaktą",
"Error saving contact to backend" => "Klaida išsaugant kontaktą į sistemą.",
"Error getting user photo" => "Klaida gaunant naudotojo nuotrauką",
"No photo path was submitted." => "Nenurodytas nuotraukos kelias. ",
"Error getting PHOTO property." => "Klaida gaunant nuotraukos  savybes.",
"Error saving contact." => "Klaida išsaugant kontaktą.",
"No group name given." => "Nepateiktas grupės pavadinimas.",
"Error adding group." => "Klaida pridedant grupę.",
"No group name to rename from given." => "Nėra grupės pavadinimo, kad pervadinti iš pateikto.",
"No group name to rename to given." => "Nėra grupės pavadinimo, kad pervadinti į pateiktą.",
"Error renaming group." => "Klaida pervadinant grupę.",
"Group ID missing from request." => "Užklausoje trūksta grupės ID.",
"Group name missing from request." => "Užklausoje trūksta grupės pavadinimo.",
"Contact ID missing from request." => "Užklausoje trūksta kontakto ID.",
"No file was uploaded. Unknown error" => "Failai nebuvo įkelti dėl nežinomos priežasties",
"There is no error, the file uploaded with success" => "Failas įkeltas sėkmingai, be klaidų",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Įkeliamo failo dydis viršija upload_max_filesize nustatymą php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Įkeliamo failo dydis viršija MAX_FILE_SIZE nustatymą, kuris naudojamas HTML formoje.",
"The uploaded file was only partially uploaded" => "Failas buvo įkeltas tik dalinai",
"No file was uploaded" => "Nebuvo įkeltas joks failas",
"Missing a temporary folder" => "Nėra laikinojo katalogo",
"Failed to write to disk" => "Nepavyko įrašyti į diską",
"Not enough storage available" => "Nepakanka vietos serveryje",
"Attempt to upload blacklisted file:" => "Bandymas įkelti draudžiamą failą:",
"Error uploading contacts to storage." => "Klaida siunčiant kontaktus į saugyklą.",
"Error moving file to imports folder." => "Klaida perkeliant failą į importavimų aplanką.",
"You do not have permissions to import into this address book." => "Jūs neturite leidimo importuoti į šią adresų knygutę.",
"File name missing from request." => "Užklausoje trūksta failo pavadinimo.",
"Progress key missing from request." => "Užklausoje trūksta eigos rakto.",
"Attempt to access blacklisted file:" => "bandymas pasiekti draudžiamą failą:",
"No key is given." => "Nepateiktas raktas.",
"No value is given." => "Nepateikta vertė.",
"Could not set preference: " => "Nepavyko nustatyti:",
"Contact" => "Kontaktas",
"Other" => "Kita",
"HomePage" => "Namų puslapis",
"Jabber" => "Jabber",
"Internet call" => "Internetinis skambutis",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "Darbas",
"Home" => "Namų",
"Mobile" => "Mobilusis",
"Text" => "Žinučių",
"Voice" => "Balso",
"Message" => "Žinutė",
"Fax" => "Faksas",
"Video" => "Vaizdo",
"Pager" => "Pranešimų gaviklis",
"Internet" => "Internetas",
"Friends" => "Draugai",
"Family" => "Šeima",
"New contact" => "Naujas kontaktas",
"Group name" => "Grupės pavadinimas",
"New group" => "Nauja grupė",
"Address books" => "Adresų knygos",
"Display name" => "Rodyti vardą",
"Add Address Book" => "Pridėti adresų knygą",
"Select file..." => "Pasirinkti failą...",
"(De-)select all" => "Nuimti pažymėjimą",
"Sort order" => "Išdėstymo tvarka",
"First- Lastname" => "Vardas- Pavardė",
"Last-, Firstname" => "Pavardė-, Vardas",
"Delete" => "Ištrinti",
"Groups" => "Grupės",
"Download" => "Atsisiųsti",
"Merge" => "Sulieti",
"Email" => "El. Paštas",
"Phone" => "Telefonas",
"Address" => "Adresas",
"Group" => "Grupė",
"Keyboard shortcuts" => "Klaviatūros spartieji klavišai",
"Navigation" => "Navigacija",
"Next contact in list" => "Kitas kontaktas sąraše",
"Previous contact in list" => "Ankstesnis kontaktas sąraše",
"Expand/collapse current addressbook" => "Išskleisti/sutraukti šią adresų knygutę",
"Next addressbook" => "Kita adresų knygutė",
"Previous addressbook" => "Ankstesnė adresų knygutė",
"Actions" => "Veiksmai",
"Refresh contacts list" => "Atnaujinti kontaktų sąrašą",
"Add new contact" => "Pridėti naują kontaktą",
"Add new addressbook" => "Pridėti naują adresų knygą",
"Delete current contact" => "Ištrinti šį kontaktą",
"Which contact should the data be merged into?" => "Į kurį kontaktą sulieti duomenis?",
"Delete the other(s) after successful merge?" => "Ištrinti kitą(-us) sėkmingai suliejus?",
"Compose mail" => "Sukurti el. laišką",
"Delete current photo" => "Ištrinti šią nuotrauką",
"Edit current photo" => "Redaguoti šią nuotrauką",
"Upload new photo" => "Įkelti naują foto",
"Favorite" => "Mėgiamas",
"Name" => "Pavadinimas",
"First name" => "Vardas",
"Additional names" => "Papildomi vardai",
"Last name" => "Pavardė",
"Nickname" => "Slapyvardis",
"Title" => "Pavadinimas",
"Organization" => "Organizacija",
"Birthday" => "Gimtadienis",
"Notes go here..." => "Pastabos rašomo čia...",
"Add field..." => "Pridėti lauką...",
"Instant Messaging" => "Tikralaikiai pokalbiai",
"Note" => "Pastaba",
"Web site" => "Svetainė",
"Preferred" => "Pageidautinas",
"Please specify a valid email address." => "Prašome nurodyti tinkamą el. pašto adresą.",
"someone@example.com" => "kasnors@pavyzdys.lt",
"Mail to address" => "Gavėjo el. pašto adresas",
"Delete email address" => "Ištrinti el. pašto adresus",
"Enter phone number" => "Įveskite telefono numerį",
"Go to web site" => "Eiti į svetainę",
"View on map" => "Žiūrėti žemėlapyje",
"Street address" => "Gatvės adresas",
"Postal code" => "Pašto kodas",
"City" => "Miestas",
"State or province" => "Šalis ar provincija",
"Country" => "Šalis",
"Instant Messenger" => "Momentinių žinučių klientas",
"Active" => "Aktyvus",
"Share" => "Dalintis",
"Export" => "Eksportuoti",
"CardDAV link" => "CardDAV nuoroda",
"Edit" => "Redaguoti",
"Description" => "Aprašymas",
"User" => "Naudotojas",
"Password" => "Slaptažodis",
"Base DN" => "Bazinis DN"
);
